Exception: HttpConnectionPool::OptionKeyError
- Inherits:
-
ConfigurationError
- Object
- StandardError
- Error
- ConfigurationError
- HttpConnectionPool::OptionKeyError
- Defined in:
- lib/http_connection_pool/errors.rb
Overview
An option value cannot be safely/canonically used as part of a pool key (e.g. an SSLContext object, whose inspect omits distinguishing material and would silently collide). See README “Error handling”.